#ifndef NT2_INCLUDE_FUNCTIONS_CBRT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CBRT_HPP_INCLUDED

#include <nt2/exponential/include/functions/cbrt.hpp>

#endif
